@@ -409,7 +409,8 @@ class QiDataController:
         if len(bar_provider.bar_series) < max_length:
             trading_date = begin_trading_date
             count = 0
-            while count < 5:
+            count_max = int(math.ceil((max_length - len(bar_provider.bar_series)) * 3.0 / n_one_day_count))
+            while count < count_max:
                 count += 1
                 trading_date = TradingDayHelper.get_pre_trading_day(trading_date)
                 if bar_provider.bar_type == EnumBarType.second:
